# Axon Edge Python SDK
Python SDK for to connect sensors to the Axon Edge cloud.

Documentation is available at https://www.axonedge.io/docs/python.

Get started connecting devices and monitoring sensor data for free with just a few lines of code.
